@@ -12,6 +12,7 @@
 #define argr4 argr4_c
 #define argr8 argr8_c
 #define argis argis_c
+#define findarg findarg_c
 
 #define C_ARGSTR argstr_c
 #define C_ARGI4 argi4_c
@@ -19,6 +20,7 @@
 #define C_ARGR4 argr4_c
 #define C_ARGR8 argr8_c
 #define C_ARGIS argis_c
+#define C_FINDARG findarg_c
 
 #ifndef _ArgSys_h
 #include <argsys.h>
