@@ -30,37 +30,35 @@ int main(argc,argv)
 int argc;
 char **argv;
 {
-	FILE *input,*output,*map_unit;
-	int i,j,trcknt,mapknt;
+	FILE *output;
+	int i,trcknt,mapknt;
 	char **from,**to,*value;
 	char *lbracket,*rbracket;
 	int offset;
 	char prtfilename[32];
 	char hostname[9],comment[80];
 	long numsmp,smpint,numtrc;
-	short  numaux, cdpfold, origsmpint, orignumsmp;
+	short  cdpfold;
 	int line_hdr_indx,trace_hdr_indx;
 	int indx,bytes,help,databytes;
-	short recno,trcno;
+	int native_trace_data;
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	char native[8];
+	int format,index,length;
+	int native_line_header, native_trace_header;
+#endif
 	char ntap[256],otap[256],map_file[256];
 	char *def_map_file;
 	char *header,*buffer;
 	int count;
 	int luin;
-	int override_samples,new_samples,new_traces,new_sample_intv,new_fold;
-	int trace_samp_flag;
 	short sval;
 	int lval;
 	float rval;
 	float unitscaler;
 	char *chval;
-	int format,index,length;
-	int *segy_hdrtype,*segy_format,*segy_index,*segy_length;
 	int TrcNumSmp_format, TrcNumSmp_index, TrcNumSmp_length;
 	int TrcIdCode_format, TrcIdCode_index, TrcIdCode_length;
-	int DstSgn_format, DstSgn_index, DstSgn_length;
-	int ElevScaler_format, ElevScaler_index, ElevScaler_length;
-	int XYUnits_format, XYUnits_index, XYUnits_length;
 	int RecNum_format, RecNum_index, RecNum_length;
 	int TrcNum_format, TrcNum_index, TrcNum_length;
 	int SrPtXC_format, SrPtXC_index, SrPtXC_length;
@@ -70,10 +68,6 @@ char **argv;
 	int DphInd_format, DphInd_index, DphInd_length;
 	int PrRcNm_format, PrRcNm_index, PrRcNm_length;
 	int PrTrNm_format, PrTrNm_index, PrTrNm_length;
-	int SrcX_format, SrcX_index, SrcX_length;
-	int SrcY_format, SrcY_index, SrcY_length;
-	int GrpX_format, GrpX_index, GrpX_length;
-	int GrpY_format, GrpY_index, GrpY_length;
 	int SrcDepth_format, SrcDepth_index, SrcDepth_length;
 	int FieldRecNum_format, FieldRecNum_index, FieldRecNum_length;
 	int FieldTrcNum_format, FieldTrcNum_index, FieldTrcNum_length;
@@ -93,11 +87,8 @@ char **argv;
 	save_struct **segy_line_hdr_map,**segy_trace_hdr_map;
 
 	short fmtcode,unitsflg;
-	int *hdrtype;
 	char jobnum[8];
 	int linetrcnum;
-	int srptxc, srptyx, rcptxc, rcptyc;
-	short dphind, prrcnm, prtrnm;
 	int segy_prrcnm, segy_prtrnm;
 	short trid, trcnumsmp, segysmpint;
 	int cdpnum, cdptrcnum;
@@ -109,6 +100,7 @@ char **argv;
 	help += C_ARGIS("-h",&argc,argv);
 	if (help > 0) {
 	  fprintf(stderr,"\nUsage: usp2segy -N[] -O[] -m mapping -M map_file");
+	  fprintf(stderr,"\n\t-native [line | trace | data| all] ");
 	  fprintf(stderr," -h -'?' -V level\n\n");
 	  fprintf(stderr,"       -N[input]   -- input data set (default=stdin)\n");
 	  fprintf(stderr,"       -O[output]  -- output data set (default=stdout)\n");
@@ -116,29 +108,32 @@ char **argv;
 	  fprintf(stderr,"                   -- map header info\n");
 	  fprintf(stderr,"       -M          -- mapping file containing entries of form\n");
 	  fprintf(stderr,"                      segy_header_mnemonic = [usp_header_mnemonic|constant]\n");
+	  fprintf(stderr,"       -native [line | trace | data | all]\n");
+	  fprintf(stderr,"                   -- native format flags\n");
 	  fprintf(stderr,"       -V          -- verbose mode\n\n");
 	  fprintf(stderr,"       -h -?       -- display this help screen\n\n");
 	  exit(1);
 	  }
 
-	sprintf(prtfilename,"USP2SEGY.%d",getpid());
-
-	if (C_IN_IKP() != 0) {
-	  if (gethostname(hostname,9) == 0) {
-	    hostname[8] = '\0';
-	    strcat(prtfilename,".");
-	    strcat(prtfilename,hostname);
-	    }
-	  }
-
-	prtfile = fopen(prtfilename,"w");
-	if (prtfile == NULL) prtfile = stderr;
-	setbuf(prtfile,NULL);
-
-	fprintf(prtfile,"USP2SEGY:\n");
-
 	C_ARGI4("-V",&verbose,1,0,&argc,argv);
 
+	if (verbose > 0) {
+	  sprintf(prtfilename,"USP2SEGY.%d",getpid());
+
+	  if (C_IN_IKP() != 0) {
+	    if (gethostname(hostname,9) == 0) {
+	      hostname[8] = '\0';
+	      strcat(prtfilename,".");
+	      strcat(prtfilename,hostname);
+	      }
+	    }
+
+	  prtfile = fopen(prtfilename,"w");
+	  if (prtfile == NULL) prtfile = stderr;
+	  setbuf(prtfile,NULL);
+	  fprintf(prtfile,"USP2SEGY:\n");
+	  }
+
 	from = (char **) malloc(150*sizeof(char *));
 	to = (char **) malloc(150*sizeof(char *));
 	indx=-1;
@@ -167,19 +162,17 @@ char **argv;
    previous specification
 */
 	  for (i=0; i<indx-1; i++) {
-	    if (strcmp(to[i],to[indx-1]) == 0) {
-		indx--;
+	    if (strcmp(to[i],to[indx]) == 0) {
 		fprintf(stderr,"USP2SEGY: Duplicate specifications for mnemonic %s;\n          %s=%s overrides previous entry of %s=%s\n",to[indx],to[indx],from[indx],to[i],from[i]);
 		if (verbose != 0) fprintf(prtfile," USP2SEGY: Duplicate specifications for mnemonic %s;\n          %s=%s overrides previous entry of %s=%s\n",to[indx],to[indx],from[indx],to[i],from[i]);
 		from[i] = from[indx];
 		to[i] = to[indx];
+	  	indx--;
 		break;
 		}
 	     }
-
 	  } while (strcmp(from[indx],"EOF") != 0);
 
-/*	indx--; */
 	mapknt = indx;	/* we don't want to count the EOF entry */
 
 	if (verbose == 1) {
@@ -193,7 +186,6 @@ char **argv;
 	C_ARGSTR("-N",ntap," "," ",&argc,argv);
 	if (strcmp(ntap," ") == 0) {
 	  if (verbose == 1) fprintf(prtfile," input file = stdin\n");
-	  input = stdin;
 	  luin = 0;
 	  }
 	else {
@@ -217,6 +209,38 @@ char **argv;
 	    }
 	  }
 
+        native_trace_data = 0;
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	native_line_header = 0;
+	native_trace_header = 0;
+	for(i=0; i<3; i++) {
+	  C_ARGSTR("-native",native,"all"," ",&argc,argv);
+	  if (strcmp(native,"line") == 0) {
+	    native_line_header = 1;
+	    }
+	  if (strcmp(native,"trace") == 0) {
+	    native_trace_header = 1;
+	    }
+	  if (strcmp(native,"data") == 0) {
+	    native_trace_data = 1;
+	    }
+	  if (strcmp(native,"all") == 0) {
+	    native_line_header = 1;
+	    native_trace_header = 1;
+	    native_trace_data = 1;
+	    }
+	  }
+
+	if (verbose != 0) {
+	  if (native_line_header == 1) fprintf(prtfile,
+		"\n Line Header is to be written in native machine format\n");
+	  if (native_trace_header == 1) fprintf(prtfile,
+		" Trace Header is to be written in native machine format\n");
+	  if (native_trace_data == 1) fprintf(prtfile,
+		" Trace Data is to be written in native machine format\n");
+	  }
+#endif
+
 /*
 need to check return codes ; we should also realloc after looking up indices
 */
@@ -259,8 +283,9 @@ need to check return codes ; we should also realloc after looking up indices
 	if (verbose != 0) {
 	  fprintf(prtfile,"\n HLH:\n");
 	  for (i=0;i<hlhknt; i++) {
-	    fprintf(prtfile,"   %3d %s\n",i,*(hlh+i));
+	    fprintf(prtfile,"   %3d %s\n",i+1,*(hlh+i));
 	    }
+	  fprintf(prtfile,"\n");
 	  }
 /*
  * need to translate the HLH to EBCDIC here (only 40 lines * 80 chars)
@@ -268,7 +293,7 @@ need to check return codes ; we should also realloc after looking up indices
 	count = 3200;
 	memset(header,(int) ' ',count);
 	for(indx=1,i=hlhknt-40;indx<=40;indx++,i++) {
-	  sprintf(comment,"C %d ",indx);
+	  sprintf(comment,"C%2d ",indx);
 	  if (i>=0) strncat(comment,*(hlh+i),80-strlen(comment));
 	  memcpy(header+((indx-1)*80),comment,strlen(comment));
 	  }
@@ -640,9 +665,11 @@ need to check return codes ; we should also realloc after looking up indices
 /* If necessary, we need to do byte rotations */
 
 #if ( BYTE_ORDER == LITTLE_ENDIAN )
-	HTOCL(header,3);
-	C_SAVELU("NumTrc",&format,&index,&length,SEGYLINEHEADER);
-	HTOCS(header+(index*sizeof(short)),25);
+	if (native_line_header != 1) {
+	  HTOCL(header,3);
+	  C_SAVELU("NumTrc",&format,&index,&length,SEGYLINEHEADER);
+	  HTOCS(header+(index*sizeof(short)),25);
+	  }
 #endif
 
 	bytes = fwrite(header,1,SEGYLINEHEADERBYTES,output);
@@ -695,17 +722,6 @@ need to check return codes ; we should also realloc after looking up indices
 	C_SAVELU("TrcIdCode",&TrcIdCode_format,&TrcIdCode_index,
 		&TrcIdCode_length,SEGYTRACEHEADER);
 
-#if ( BYTE_ORDER == LITTLE_ENDIAN )
-	C_SAVELU("DstSgn",&DstSgn_format,&DstSgn_index,
-		&DstSgn_length,SEGYTRACEHEADER);
-	C_SAVELU("ElevScaler",&ElevScaler_format,&ElevScaler_index,
-		&ElevScaler_length,SEGYTRACEHEADER);
-	C_SAVELU("SrcX",&SrcX_format,&SrcX_index,
-		&SrcX_length,SEGYTRACEHEADER);
-	C_SAVELU("XYUnits",&XYUnits_format,&XYUnits_index,
-		&XYUnits_length,SEGYTRACEHEADER);
-#endif
-
 /* look up indexes to speed things up in trace loop */
 
 	C_SAVELU("RecNum", &RecNum_format, &RecNum_index, &RecNum_length,
@@ -726,15 +742,6 @@ need to check return codes ; we should also realloc after looking up indices
 			TRACEHEADER);
 	C_SAVELU("PrTrNm", &PrTrNm_format, &PrTrNm_index, &PrTrNm_length,
 			TRACEHEADER);
-
-	C_SAVELU("SrcX", &SrcX_format, &SrcX_index, &SrcX_length,
-			SEGYTRACEHEADER);
-	C_SAVELU("SrcY", &SrcY_format, &SrcY_index, &SrcY_length,
-			SEGYTRACEHEADER);
-	C_SAVELU("GrpX", &GrpX_format, &GrpX_index, &GrpX_length,
-			SEGYTRACEHEADER);
-	C_SAVELU("GrpY", &GrpY_format, &GrpY_index, &GrpY_length,
-			SEGYTRACEHEADER);
 	C_SAVELU("SrcDepth", &SrcDepth_format, &SrcDepth_index,
 			&SrcDepth_length, SEGYTRACEHEADER);
 	C_SAVELU("FieldRecNum", &FieldRecNum_format, &FieldRecNum_index,
@@ -830,7 +837,7 @@ need to check return codes ; we should also realloc after looking up indices
 			LINEHEADER,&lval);
 		  else {
 		    lval = atol(trace_hdr_map[indx].tag);
-		    if ((sval == 0) && (errno != 0)) {
+		    if ((lval == 0) && (errno != 0)) {
 			fprintf(stderr,"Invalid constant specification %s=%s\n",
 				segy_trace_hdr_map[indx]->tag,
 				trace_hdr_map[indx].tag);
@@ -899,7 +906,7 @@ need to check return codes ; we should also realloc after looking up indices
 		header+SEGYTRACEHEADERBYTES+(j*sizeof(float)));
 */
 #if ( BYTE_ORDER == LITTLE_ENDIAN )
-	  float_to_ibm(buffer+SZTRHD, header+SEGYTRACEHEADERBYTES, numsmp, 0);
+	  float_to_ibm(buffer+SZTRHD, header+SEGYTRACEHEADERBYTES, numsmp, native_trace_data);
 	  HTOCL(buffer+SZTRHD,numsmp);
 #else
 	  float_to_ibm(buffer+SZTRHD, header+SEGYTRACEHEADERBYTES, numsmp, 1);
@@ -907,17 +914,19 @@ need to check return codes ; we should also realloc after looking up indices
 
 
 #if ( BYTE_ORDER == LITTLE_ENDIAN )
-	  HTOCL(header,7);
-	  C_SAVELU("TrcIdCode",&format,&index,&length,SEGYTRACEHEADER);
-	  HTOCS(header+(index*sizeof(short)),4);
-	  C_SAVELU("DstSgn",&format,&index,&length,SEGYTRACEHEADER);
-	  HTOCL(header+(index*sizeof(long)),8);
-	  C_SAVELU("ElevScaler",&format,&index,&length,SEGYTRACEHEADER);
-	  HTOCS(header+(index*sizeof(short)),2);
-	  C_SAVELU("SrcX",&format,&index,&length,SEGYTRACEHEADER);
-	  HTOCL(header+(index*sizeof(long)),4);
-	  C_SAVELU("XYUnits",&format,&index,&length,SEGYTRACEHEADER);
-	  HTOCS(header+(index*sizeof(short)),46);
+	  if (native_trace_header != 1) {
+	    HTOCL(header,7);
+	    C_SAVELU("TrcIdCode",&format,&index,&length,SEGYTRACEHEADER);
+	    HTOCS(header+(index*sizeof(short)),4);
+	    C_SAVELU("DstSgn",&format,&index,&length,SEGYTRACEHEADER);
+	    HTOCL(header+(index*sizeof(long)),8);
+	    C_SAVELU("ElevScaler",&format,&index,&length,SEGYTRACEHEADER);
+	    HTOCS(header+(index*sizeof(short)),2);
+	    C_SAVELU("SrcX",&format,&index,&length,SEGYTRACEHEADER);
+	    HTOCL(header+(index*sizeof(long)),4);
+	    C_SAVELU("XYUnits",&format,&index,&length,SEGYTRACEHEADER);
+	    HTOCS(header+(index*sizeof(short)),46);
+	    }
 #endif
 	  bytes = fwrite(header,1,SEGYTRACEHEADERBYTES+databytes,output);
 	  }
