@@ -311,7 +311,7 @@ void check_server(XtPointer id,XtIntervalId *id_tmp)
 */
 void get_dataCB(Widget w, XtPointer client_data, XtPointer call_data)
 {
-  String str, formatString;
+  String str;
   int n,offset;
   long id;	/* RJM: handle 64-bit architectures */
 
@@ -487,7 +487,6 @@ void data(Widget w, long id, Boolean flag_old)
   Widget form,tform;
   Widget slabel;
   Widget frame,tframe;
-  Widget temp_widget;
   Widget label;
   Widget button;
   Widget row_column;
@@ -1885,7 +1884,7 @@ static void getCB(Widget w, XtPointer client_data, XtPointer call_data)
       (((etrace[id]-strace[id])/itrace[id])+1);
     height=((esamp[id]-ssamp[id])/isamp[id])+1;
   } else {
-    trace_flag=False;
+    /* trace_flag=False; - this made single sample plots break - jmw 1/14/01 */
     width=((etrace[id]-strace[id])/itrace[id])+1;
     height=((erec[id]-srec[id])/irec[id])+1;
   }
@@ -1961,12 +1960,12 @@ RJM */
     data=NULL;
   }
 
-				/* Get the scale and offset factors used. */
+  /* Get the scale and offset factors used. */
   xdisplay[id].offset=amoco_offset();
   xdisplay[id].scalar=amoco_scalar();
 
-				
-  if (xdisplay[id].flip_flag) {		/* Flip raster image right to left. */
+  /* Flip raster image right to left. */
+  if (xdisplay[id].flip_flag) {	
     for (m=0; m<height; m++)
       for (n=0; n<(width/2); n++) {
 	temp=*(raster[id]+n+m*width);
@@ -1975,7 +1974,8 @@ RJM */
       }
   }
 				
-  if (xdisplay[id].upside_flag) {	/* Flip raster image upside-down. */
+  /* Flip raster image upside-down. */
+  if (xdisplay[id].upside_flag) {
     for (m=0; m<(height/2); m++)
       for (n=0; n<width; n++) {
 	temp=*(raster[id]+n+m*width);
@@ -1984,7 +1984,8 @@ RJM */
       }
   }
 
-  if( xdisplay[id].swap_flag )	/* Swap x & y axes */	/* RJM */
+  /* Swap x & y axes */
+  if (xdisplay[id].swap_flag)
   {
 	transpose_image = transpose( raster[id], width, height );
 	free( raster[id] );
